import { isEqual } from 'lodash-es';
/**
 * 判断深度两个数据是否相等
 * @param aDeps
 * @param bDeps
 * @returns
 */
export var depsEqual = function depsEqual() {
  var aDeps = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var bDeps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  return isEqual(aDeps, bDeps);
};

/**
 * 判断是不是函数
 * @param fn{*} 需要判断的值
 * @returns
 */
export var isFunction = function isFunction(fn) {
  return typeof fn === 'function';
};

/**
 * 将驼峰字符串以-分割
 * @param str
 * @returns
 */
export function getCamelCase(str) {
  return str.replace(/-([a-z])/g, function (all, i) {
    return i.toUpperCase();
  });
}

/**
 * 判断元素是否可滚动
 * @param  HTMLElement dom元素
 * @return boolean
 */
export var isScrollable = function isScrollable(ele) {
  var hasScrollableContent = (ele === null || ele === void 0 ? void 0 : ele.scrollHeight) > (ele === null || ele === void 0 ? void 0 : ele.clientHeight);
  var overflowYStyle = window.getComputedStyle(ele).overflowY;
  var isOverflowHidden = overflowYStyle.indexOf('hidden') !== -1;
  return hasScrollableContent && !isOverflowHidden;
};

/**
 * 查找当前元素以及父元素直到body 可以滚动的元素
 * @param HTMLElement 元素
 * @returns HTMLElement
 */
export var getScrollableParent = function getScrollableParent(ele) {
  if (!ele || ele === document.body) {
    return document.body;
  } else if (isScrollable(ele)) {
    return ele;
  } else {
    return getScrollableParent(ele === null || ele === void 0 ? void 0 : ele.parentNode);
  }
};

/**
 * 判断是不是苹果Safari浏览器
 */
export var isSafari = function isSafari() {
  return /Safari/.test(navigator.userAgent) && !/Chrome/.test(navigator.userAgent);
};

/**
 * 判断苹果Safari屏幕的方向
 */
export function getScreenOrientation() {
  if (window.innerHeight > window.innerWidth) {
    return 'portrait'; // 竖屏
  } else {
    return 'landscape'; // 横屏
  }
}